signals

package
v0.0.0-...-bcdc46a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2025 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var QuitChan = make(chan struct{})

Functions

func CloseQuitChan

func CloseQuitChan()

CloseQuitChan sends a global signal that service is about to shutdown.

func NewMessageNotify

func NewMessageNotify(c chan struct{})

NewMessageNotify sends an empty message into the channel if there is a space available for it.

Types

This section is empty.

Jump to