Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var QuitChan = make(chan struct{})
Functions ¶
func CloseQuitChan ¶
func CloseQuitChan()
CloseQuitChan sends a global signal that service is about to shutdown.
func NewMessageNotify ¶
func NewMessageNotify(c chan struct{})
NewMessageNotify sends an empty message into the channel if there is a space available for it.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.